﻿using Syncfusion.ListView.XForms;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;
using Xamarin.Forms.Internals;

namespace SfListViewSample
{
    [Preserve(AllMembers = true)]

    #region DataTemplateSelectorBehavior

    public class DataTemplateSelectorBehavior : Behavior<Syncfusion.ListView.XForms.SfListView>
    {
        #region Fields

        private ViewModel DataTemplateSelectorViewModel;
        private Syncfusion.ListView.XForms.SfListView ListView;
        private ScrollView scrollView;

        #endregion

        #region Overrides
        protected override void OnAttachedTo(Syncfusion.ListView.XForms.SfListView bindable)
        {
            ListView = bindable;
            base.OnAttachedTo(bindable);
            DataTemplateSelectorViewModel = new ViewModel();
            DataTemplateSelectorViewModel.ListView = ListView;
            ListView.BindingContext = DataTemplateSelectorViewModel;
            ListView.Loaded += ListView_Loaded;
            ListView.ItemTapped += ListView_ItemTapped;
            ListView.ItemsSource = DataTemplateSelectorViewModel.MessageInfo;
        }

        private void ListView_Loaded(object sender, ListViewLoadedEventArgs e)
        {
            scrollView = ListView.Parent as ScrollView;
            ListView.HeightRequest = scrollView.Height;

            if (Device.RuntimePlatform == Device.macOS)
            {
                Device.BeginInvokeOnMainThread(() =>
                {
                    ListView.ScrollTo(2500);
                });
            }
            else
            {
                Device.BeginInvokeOnMainThread(() =>
                {
                    (ListView.LayoutManager as LinearLayout).ScrollToRowIndex(DataTemplateSelectorViewModel.MessageInfo.Count - 1, Syncfusion.ListView.XForms.ScrollToPosition.Start);
                });
            }
        }

        private void ListView_ItemTapped(object sender, Syncfusion.ListView.XForms.ItemTappedEventArgs e)
        {
            if (e.ItemData == null)
                return;

            var item = e.ItemData as MessageInfo;
            DataTemplateSelectorViewModel.MessageInfo.Remove(item);
            App.Current.MainPage.DisplayAlert("Message","Deleted Item : " +item.Text,"Ok");
        }

        protected override void OnDetachingFrom(Syncfusion.ListView.XForms.SfListView bindable)
        {
            ListView = null;
            base.OnDetachingFrom(bindable);
        }

        #endregion

    }

    #endregion
}
