﻿using Syncfusion.ListView.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;
using Xamarin.Forms;
using Xamarin.Forms.Internals;

namespace SfListViewSample
{
    [Preserve(AllMembers = true)]
    class ViewModel : INotifyPropertyChanged
    {
        #region Fields

        private ObservableCollection<MessageInfo> messageInfo;
        private string newText;

        internal Syncfusion.ListView.XForms.SfListView ListView;
        private ImageSource sendIcon;

        #endregion

        #region Properties

        public Command<object> DeleteCommand { get; set; }
        public ObservableCollection<MessageInfo> MessageInfo
        {
            get { return messageInfo; }
            set { this.messageInfo = value; }
        }

        public string NewText
        {
            get { return newText; }
            set
            {
                newText = value;
                OnPropertyChanged("NewText");
            }
        }

        public ImageSource SendIcon
        {
            get
            { return sendIcon; }
            set
            { sendIcon = value; }
        }

        public ICommand SendCommand { get; set; }

        #endregion

        #region Interface

        public event PropertyChangedEventHandler PropertyChanged;
        protected void OnPropertyChanged(string propertyName = "")
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion Interface

        #region Constructor
        public ViewModel()
        {
            InitializeSendCommand();
            DeleteCommand = new Command<object>(DeleteCommandMethod);
           GenerateSource();
        }

        private void DeleteCommandMethod(object obj)
        {
            var item = obj as MessageInfo;
            this.MessageInfo.Remove(item);
            App.Current.MainPage.DisplayAlert("Message","Item Deleted :" +item.Text,"Ok");
        }

        #endregion

        #region GenerateSource
        public void GenerateSource()
        {
            MessageInfoRepository Message = new MessageInfoRepository();
            MessageInfo = Message.GenerateInfo();
        }

        #endregion

        #region InitializeCommand
        private void InitializeSendCommand()
        {
            Assembly assembly = typeof(DataTemplateSelector).GetTypeInfo().Assembly;
            SendIcon = ImageSource.FromResource("SfListViewSample.Images.SendIcon.png", assembly);
            NewText = "";
            SendCommand = new Command(() =>
            {
                if (!string.IsNullOrWhiteSpace(NewText))
                {
                    MessageInfo.Add(new MessageInfo
                    {

                        OutgoingMessageIndicator = ImageSource.FromResource("SfListViewSample.Images.OutgoingIndicatorImage.png", assembly),
                        Text = NewText,
                        TemplateType = TemplateType.IncomingText,
                        DateTime = string.Format("{0:HH:mm}", DateTime.Now)
                    });
                    (ListView.LayoutManager as LinearLayout).ScrollToRowIndex(MessageInfo.Count - 1, Syncfusion.ListView.XForms.ScrollToPosition.Start);
                }
                NewText = null;
            });
        }

        #endregion
    }
}
